<template>
  <el-dialog
    width="50%"
    title="物料需求"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
    :close-on-click-modal="false"
  >
    <div>
      <div
        style="display:flex;height:36px;justify-content: space-between;align-items:center;"
      >
        <div><span style="font-weight:bold;">物料需求</span></div>
        <div>
          <el-button type="text" @click="openPartDialog">新增</el-button>
        </div>
      </div>
      <div>
        <el-table
          class="operation-material-table"
          :data="operationMaterialData"
          style="width: 100%;"
          height="350px"
          border
          stripe
          ref="operationMaterialTable"
        >
          <el-table-column type="index" width="50" align="center" label="序号">
          </el-table-column>
          <el-table-column
            prop="partNo"
            label="零件号"
            align="center"
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            prop="partName"
            label="零件描述"
            align="center"
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            prop="demandQuantity"
            label="需求数量"
            align="center"
          >
            <template slot-scope="scope">
              <el-input v-model="scope.row.demandQuantity"></el-input>
            </template>
          </el-table-column>
          <el-table-column prop="unit" label="计量单位" align="center">
          </el-table-column>
          <el-table-column label="操作" align="center" width="85">
            <template slot-scope="scope">
              <el-button
                type="text"
                :disabled="scope.row.detailExistState"
                @click="delMaterial(scope.row, scope.$index)"
                >删除</el-button
              >
            </template>
          </el-table-column>
        </el-table>
      </div>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >确 定</el-button
      >
    </div>
    <!-- 弹窗, 零件列表 -->
    <partDialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPartCallback"
    />
  </el-dialog>
</template>
<script>
import { addReserve } from '@/api/plan/operationtask'
import { batchSavePalletTransports } from '@/api/warehouse/pallettransports'
import partDialog from '@/views/common/part.vue'
export default {
  components: { partDialog },
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    operationTasks: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      operationMaterialData: [],
      showPart: false
    }
  },
  methods: {
    // 打开零件选择对话框
    openPartDialog() {
      this.showPart = true
    },
    delMaterial(row, index) {
      console.log('index', index)
      this.operationMaterialData.splice(index, 1)
    },
    // 物料选中后的回调
    selectPartCallback(row) {
      if (row) {
        this.operationMaterialData.push({
          partId: row.id,
          partName: row.partName,
          partNo: row.partNo,
          unit: row.unit,
          demandQuantity: 0
        })
      }
    },
    checkQuality() {
      // 勾选合计校验，是否大于需求数量
      let flag = true
      let flagMsg = ''
      for (let i = 0; i < this.operationMaterialData.length; i++) {
        if (
          this.operationMaterialData[i].demandQuantity == null ||
          this.operationMaterialData[i].demandQuantity == ''
        ) {
          flag = false
          flagMsg = flagMsg + '第' + (i + 1) + '行，需求数量不能为空；'
        } else {
          if (!this.checkZero(this.operationMaterialData[i].demandQuantity)) {
            flag = false
            flagMsg = flagMsg + '第' + (i + 1) + '行，需求数量不能为0；'
          } else {
            if (
              !this.checkPositive(this.operationMaterialData[i].demandQuantity)
            ) {
              flag = false
              flagMsg = flagMsg + '第' + (i + 1) + '行，需求数量需为正数；'
            } else {
              if (
                !this.checkDecimal(this.operationMaterialData[i].demandQuantity)
              ) {
                flag = false
                flagMsg =
                  flagMsg + '第' + (i + 1) + '行，需求数量最多六位小数；'
              }
            }
          }
        }
      }
      if (!flag) {
        this.$message.error(flagMsg)
      }
      return flag
    },
    checkZero(value) {
      if (value == 0) {
        return false
      } else {
        return true
      }
    },
    checkPositive(value) {
      if (!/^[0-9]+.?[0-9]*$/.test(value)) {
        return false
      } else {
        return true
      }
    },
    checkDecimal(value) {
      if (
        !/(^[1-9]([0-9]+)?(\.[0-9]{1,6})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,6}$)/.test(
          value
        )
      ) {
        return false
      } else {
        return true
      }
    },
    saveSelectRow() {
      this.isSubmit = true
      const flag = this.checkQuality()
      if (flag) {
        let ids = ''
        this.operationTasks.forEach((item) => {
          ids = ids + item.id + '_'
        })
        ids = ids.substring(0, ids.length - 1)
        batchSavePalletTransports(this.operationMaterialData, ids)
          .then((response) => {
            const resData = response.data
            if (resData.code === 0) {
              this.innerVisible = false
              this.$message.success('创建货盘运输任务成功')
            } else {
              this.$message.error('创建货盘运输任务失败')
            }
            this.isSubmit = false
          })
          .catch(() => {
            this.isSubmit = false
          })
      } else {
        this.isSubmit = false
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.operationMaterialData = []
        this.$nextTick(() => {
          if (this.operationTasks.length > 0) {
            const ids = []
            this.operationTasks.forEach((item) => {
              ids.push(item.id)
            })
            addReserve(ids).then((response) => {
              const resData = response.data
              if (resData.code === 0) {
                const dataList = resData.data
                dataList.forEach((item) => {
                  this.operationMaterialData.push({
                    partId: item.partId,
                    partName: item.partName,
                    partNo: item.partNo,
                    unit: item.unit,
                    demandQuantity: item.demandQuantity
                  })
                })
              }
            })
          }
        })
      }
    }
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
